/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.5 Funktionen Ganglinie
 * Copyright (C) 2011-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.gllib.gllib.domain;

import java.time.LocalDateTime;

import de.bsvrz.iav.gllib.gllib.shared.LocalDateTimeKonverter;

/**
 * Präsentation eines Zustandswechsels für Ereignise als Bestandteil der Antwort
 * vom Ereigniskalender.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public final class ZustandsWechsel {

    private final Ereignis ereignis;
    private final boolean verkehrlichGueltig;
    private final boolean zeitlichGueltig;
    private final LocalDateTime zeitpunkt;

    private ZustandsWechsel(LocalDateTime zeitpunkt, Ereignis ereignis, boolean verkehrlichGueltig, boolean zeitlichGueltig) {
        this.ereignis = ereignis;
        this.verkehrlichGueltig = verkehrlichGueltig;
        this.zeitlichGueltig = zeitlichGueltig;
        this.zeitpunkt = zeitpunkt;
    }

    public static ZustandsWechsel of(LocalDateTime zeitpunkt, Ereignis ereignis, boolean verkehrlichGueltig,
            boolean zeitlichGueltig) {
        return new ZustandsWechsel(zeitpunkt, ereignis, verkehrlichGueltig, zeitlichGueltig);
    }

    public static ZustandsWechsel of(long zeitpunkt, Ereignis ereignis, boolean verkehrlichGueltig,
            boolean zeitlichGueltig) {
        return new ZustandsWechsel(LocalDateTimeKonverter.fromMillis(zeitpunkt), ereignis, verkehrlichGueltig, zeitlichGueltig);
    }

    public Ereignis getEreignis() {
        return ereignis;
    }

    public LocalDateTime getZeitpunkt() {
        return zeitpunkt;
    }
    
    public boolean isVerkehrlichGueltig() {
        return verkehrlichGueltig;
    }

    public boolean isZeitlichGueltig() {
        return zeitlichGueltig;
    }

    @Override
    public String toString() {
        return "ZustandsWechsel [ereignis=" + ereignis + ", verkehrlichGueltig=" + verkehrlichGueltig
                + ", zeitlichGueltig=" + zeitlichGueltig + ", zeitpunkt=" + zeitpunkt + "]";
    }
}
