/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.5 Funktionen Ganglinie
 * Copyright (C) 2011-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.gllib.gllib.domain.comm;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import de.bsvrz.iav.gllib.gllib.domain.GanglinienAnfrager;
import de.bsvrz.iav.gllib.gllib.domain.MqGanglinie;

/**
 * Antwort auf eine Anfrage an die Ganglinienprognose zur Ermittlung einer
 * Prognose-Ganglinie.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class GlProgAntwort {

    private final GanglinienAnfrager anfrager;
    
    /** Eine beliebige Zeichenkette die der Absender frei eingetragen kann. */
    private final String absenderZeichen;

    /** Die Liste der Prognoseganglinien in der Antwort. */
    private final List<MqGanglinie> prognosen;

    public GlProgAntwort(GanglinienAnfrager anfrager, String absenderZeichen, List<MqGanglinie> prognosen) {
        this.anfrager = Objects.requireNonNull(anfrager);
        this.absenderZeichen = Objects.requireNonNull(absenderZeichen);
        this.prognosen = new ArrayList<>(Objects.requireNonNull(prognosen));
    }

    public GanglinienAnfrager getAnfrager() {
        return anfrager;
    }
    
    /**
     * Gibt das Zeichen des Absenders zurück. Der Text wurde bei der Anfrage in die
     * Anfragenachricht eingetragen und von der Ganglinienprognose in die Antwort
     * kopiert. Somit kann die anfragende Applikation mehrere Anfragen
     * unterscheiden.
     *
     * @return das Absenderzeichen.
     */
    public String getAbsenderZeichen() {
        return absenderZeichen;
    }

    /**
     * Gibt die Menge der prognostizierten Ganglinien zurück.
     * <p>
     * <em>Hinweis:</em> Es werden nicht alle Eigenschaften der Ganglinie in der
     * Prognoseganglinie gesetzt. Gesetzt werden nur die Stütztstellen, das
     * Approximationsverfahren und der Messquerschnitt.
     *
     * @return eine Menge von Ganglinien.
     */
    public List<MqGanglinie> getGanglinien() {
        return prognosen;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        String s = getClass().getName() + "[";

        s += "absenderZeichen" + absenderZeichen;
        s += ", prognosen=" + prognosen;

        return s + "]";
    }

}
