/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.5 Funktionen Ganglinie
 * Copyright (C) 2011-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.gllib.gllib.domain.comm;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;

import de.bsvrz.iav.gllib.gllib.domain.EreignisTyp;
import de.bsvrz.iav.gllib.gllib.domain.GanglinieAnfrageTyp;
import de.bsvrz.iav.gllib.gllib.domain.GanglinienAnfrager;
import de.bsvrz.iav.gllib.gllib.domain.MessQuerschnitt;
import de.bsvrz.iav.gllib.gllib.domain.MqGanglinie;

/**
 * Basisklasse für Anfragen an den Ganglinienspeicher.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public abstract class GlSpeicherAnfrage {

    private final GanglinieAnfrageTyp typ;
    private final GanglinienAnfrager anfrager;
    private final String absenderZeichen;
    private final MessQuerschnitt messQuerschnitt;
    private final Collection<EreignisTyp> ereignisTypen = new LinkedHashSet<>();
    private final Set<Long> ganglinienId = new LinkedHashSet<>();
    private final List<MqGanglinie> ganglinien = new ArrayList<>();

    protected GlSpeicherAnfrage(GanglinieAnfrageTyp typ, GanglinienAnfrager anfrager, String absenderZeichen,
            MessQuerschnitt messQuerschnitt, Collection<EreignisTyp> ereignisTypen, Collection<Long> ganglinienId,
            List<MqGanglinie> ganglinien) {
        this.typ = typ;
        this.anfrager = anfrager;
        this.absenderZeichen = absenderZeichen;
        this.messQuerschnitt = messQuerschnitt;
        this.ereignisTypen.addAll(ereignisTypen);
        this.ganglinienId.addAll(ganglinienId);
        this.ganglinien.addAll(ganglinien);
    }

    public GanglinienAnfrager getAnfrager() {
        return anfrager;
    }

    public String getAbsenderZeichen() {
        return absenderZeichen;
    }

    public MessQuerschnitt getMessQuerschnitt() {
        return messQuerschnitt;
    }

    public Collection<EreignisTyp> getEreignisTypen() {
        return Collections.unmodifiableCollection(ereignisTypen);
    }

    public Collection<Long> getGanglinienId() {
        return Collections.unmodifiableCollection(ganglinienId);
    }

    public GanglinieAnfrageTyp getTyp() {
        return typ;
    }
    
    public List<MqGanglinie> getGanglinien() {
        return Collections.unmodifiableList(ganglinien);
    }
}
